.. _chapter_1_introduction:

Chapter 1: Introduction
=======================

In chapter 1, we introduce you to the **PyAutoFit** and describe how to set up your own model, fit it to data via
a non-linear search and inspect and interpret the results.

The chapter contains the following tutorials:

`Tutorial 1: Model Mapping <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/664a86aa84ddf8fdf044e2e4e7db21876ac1de91?filepath=howtofit%2Fchapter_1_introduction%2Ftutorial_1_model_mapping.ipynb>`_
- The **PyAutoFit** backend that handles model composition.

`Tutorial 2: Model Fitting <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/664a86aa84ddf8fdf044e2e4e7db21876ac1de91?filepath=howtofit%2Fchapter_1_introduction%2Ftutorial_2_model_fitting.ipynb>`_
- Fitting a model with an input set of parameters to data.

`Tutorial 3: Non Linear Search <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/664a86aa84ddf8fdf044e2e4e7db21876ac1de91?filepath=howtofit%2Fchapter_1_introduction%2Ftutorial_3_non_linear_search.ipynb>`_
- Finding the model parameters that best-fit the data.

`Tutorial 4: Visualization <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/664a86aa84ddf8fdf044e2e4e7db21876ac1de91?filepath=howtofit%2Fchapter_1_introduction%2Ftutorial_4_visualization.ipynb>`_
- Outputting images during the model-fit and masking your data.

`Tutorial 5: Complex Models  <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/664a86aa84ddf8fdf044e2e4e7db21876ac1de91?filepath=howtofit%2Fchapter_1_introduction%2Ftutorial_5_complex_models.ipynb>`_
- Composing and fitting complex models.

`Tutorial 6: Data Extensions  <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/664a86aa84ddf8fdf044e2e4e7db21876ac1de91?filepath=howtofit%2Fchapter_1_introduction%2Ftutorial_6_data_extensions.ipynb>`_
- Extending the Analysis class with model-specific data strructures and visualization.

`Tutorial 7: Results and Samples <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/664a86aa84ddf8fdf044e2e4e7db21876ac1de91?filepath=howtofit%2Fchapter_1_introduction%2Ftutorial_7_results_and_samples.ipynb>`_
- The results of a model-fit output by **PyAutoFit**.

`Tutorial 8: Fitting Multiple Datasets <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/664a86aa84ddf8fdf044e2e4e7db21876ac1de91?filepath=howtofit%2Fchapter_1_introduction%2Ftutorial_8_fitting_multiple_datasets.ipynb>`_
- Fitting a model to multiple similar datasets.

`Tutorial 9: Aggregator <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/664a86aa84ddf8fdf044e2e4e7db21876ac1de91?filepath=howtofit%2Fchapter_1_introduction%2Ftutorial_9_aggregator.ipynb>`_
- Loading large libraries of results using in-built database tools.

`Tutorial 10: Filtering <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/664a86aa84ddf8fdf044e2e4e7db21876ac1de91?filepath=howtofit%2Fchapter_1_introduction%2Ftutorial_10_filtering.ipynb>`_
- Filtering the loaded results to find specific results of interest.

`Tutorial 11: Data and Models <https://mybinder.org/v2/gh/Jammy2211/autofit_workspace/664a86aa84ddf8fdf044e2e4e7db21876ac1de91?filepath=howtofit%2Fchapter_1_introduction%2Ftutorial_11_data_and_models.ipynb>`_
- Replotting the model, data and fits of a set of results.
